@@ -17,7 +17,9 @@ _deleted = 'deleted'
 def _servers():
     res = cfg_read().get('sql_server', {})
     if isinstance(res, dict):
-        res[None] = res.get('null', None)
+        res[None] = res.get('null')
+        res[True] = res.get('true')
+        res[False] = res.get('false')
     return res
 
 @cache
@@ -231,6 +233,8 @@ def sql_table(table, db = None, non_null = None, nullable = None, _id = None, sc
         nullables = [Column(k.lower(), _types.get(t, t)) for k, t in nullable.items() if k not in col_names] 
         docs = [Column(doc, String, nullable = True)] if doc is not None else []
         cols = cols + non_nulls + nullables + docs
+        if len(cols) == 0:
+            raise ValueError('You seem to be trying to create a table with no columns? Perhaps you are trying to point to an existing table and getting its name wrong?')
         tbl = Table(table_name, meta, *cols)
         meta.create_all(e)
     else:
@@ -627,6 +631,14 @@ class sql_cursor(object):
         """
         return ulist(sorted(set(as_list(self.pk))))
 
+    @property
+    def reset(self):
+        res = self.copy()
+        res.spec = None
+        res.selection = None
+        res.order = None
+        return res
+
     def find(self, *args, **kwargs):
         """
         This returns a table with additional filtering. note that you can build it iteratively
@@ -648,11 +660,10 @@ class sql_cursor(object):
         ---------
         >>> t.inc(name = 'yoav').exc(t.c.age > 30) ## all the yoavs aged 30 or less        
         """
-        res = self.copy()
         if len(args) == 0 and len(kwargs) == 0:
-            res.spec = None
-            return res
-        elif len(kwargs) > 0 and len(args) == 0:
+            return self
+        res = self.copy()
+        if len(kwargs) > 0 and len(args) == 0:
             e = self._c(kwargs)
         elif len(args) > 0 and len(kwargs) == 0:
             e = self._c(args)
@@ -737,9 +748,11 @@ class sql_cursor(object):
     def columns(self):
         return ulist([col.name for col in self.table.columns])
 
-    def select(self, value = None):
+    def select(self, *value):
+        if len(value) == 0:
+            return self
         res = self.copy()
-        res.selection = value
+        res.selection = as_list(value)
         return res
     
     def _enrich(self, doc, columns = None):
